pub enum Operation {
Create {
notification_key_name: String,
registration_ids: Vec<String>,
},
Add {
notification_key_name: Option<String>,
notification_key: String,
registration_ids: Vec<String>,
},
Remove {
notification_key_name: Option<String>,
notification_key: String,
registration_ids: Vec<String>,
},
}Expand description
Represents a POST operation to fcm. See https://firebase.google.com/docs/cloud-messaging/android/device-group
Variants
Create
Create a new device group with the following name See https://firebase.google.com/docs/cloud-messaging/android/device-group#creating_a_device_group
Fields
Add
Add a devices to the device group See https://firebase.google.com/docs/cloud-messaging/android/device-group#adding_and_removing_devices_from_a_device_group
Fields
Remove
Remove a device from a device group See https://firebase.google.com/docs/cloud-messaging/android/device-group#adding_and_removing_devices_from_a_device_group