pub struct FCMDeviceGroupClient { /* private fields */ }Expand description
Client to use fcm device groups
Implementations
Sourceimpl FCMDeviceGroupClient
impl FCMDeviceGroupClient
Sourcepub fn new(
sender_id: &str,
auth: impl GetToken + 'static,
) -> Result<Self, FCMDeviceGroupClientCreationError>
pub fn new( sender_id: &str, auth: impl GetToken + 'static, ) -> Result<Self, FCMDeviceGroupClientCreationError>
Creates a new FCMDeviceGroupClient with the default url and the provided bearer auth string
Sourcepub fn with_url(
url: impl IntoUrl,
sender_id: &str,
auth: impl GetToken + 'static,
) -> Result<Self, FCMDeviceGroupClientCreationError>
pub fn with_url( url: impl IntoUrl, sender_id: &str, auth: impl GetToken + 'static, ) -> Result<Self, FCMDeviceGroupClientCreationError>
Creates a new FCMDeviceGroupClient with the given url and the provided bearer auth string
Sourcepub fn with_client(
client: HttpClient,
url: impl IntoUrl,
auth: impl GetToken + 'static,
) -> Self
pub fn with_client( client: HttpClient, url: impl IntoUrl, auth: impl GetToken + 'static, ) -> Self
Creates a new FCMDeviceGroupClient with the given url and client. Note that the creator of the client
is responsible for adding authorization headers
Sourcepub async fn apply(
&self,
operation: Operation,
) -> Result<OperationResponse, FCMDeviceGroupsRequestError<FCMDeviceGroupsBadRequest>>
pub async fn apply( &self, operation: Operation, ) -> Result<OperationResponse, FCMDeviceGroupsRequestError<FCMDeviceGroupsBadRequest>>
Apply the given operation with with the client.
Sourcepub async fn create_group(
&self,
notification_key_name: String,
registration_ids: Vec<String>,
) -> OperationResult<FCMDeviceGroup, CreateGroupError>
pub async fn create_group( &self, notification_key_name: String, registration_ids: Vec<String>, ) -> OperationResult<FCMDeviceGroup, CreateGroupError>
Create a new group with the provided name and ID
Sourcepub async fn add_to_group(
&self,
group: FCMDeviceGroup,
registration_ids: Vec<String>,
) -> OperationResult<FCMDeviceGroup, ChangeGroupMembersError>
pub async fn add_to_group( &self, group: FCMDeviceGroup, registration_ids: Vec<String>, ) -> OperationResult<FCMDeviceGroup, ChangeGroupMembersError>
Add a set of registration IDS to the group
Sourcepub async fn remove_from_group(
&self,
group: FCMDeviceGroup,
registration_ids: Vec<String>,
) -> OperationResult<FCMDeviceGroup, ChangeGroupMembersError>
pub async fn remove_from_group( &self, group: FCMDeviceGroup, registration_ids: Vec<String>, ) -> OperationResult<FCMDeviceGroup, ChangeGroupMembersError>
Remove a set of registration IDS to the group
Sourcepub async fn get_key(
&self,
notification_key_name: String,
) -> OperationResult<FCMDeviceGroup, GetKeyError>
pub async fn get_key( &self, notification_key_name: String, ) -> OperationResult<FCMDeviceGroup, GetKeyError>
Use this client to request the notification key for a given name